JsDoc Reference - ColVis#dom

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:17 GMT-0000 (GMT)
HTML template: Codeview

# Namespace ColVis#dom

Common and useful DOM elements for the class instance
Defined in: ColVis.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| ColVis#dom

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | ColVis#dom.background Background node used for shading the display and event capturing
<static> | ColVis#dom.button Activation button
<static> | ColVis#dom.buttons List of button elements
<static> | ColVis#dom.catcher Element to position over the activation button to catch mouse events when using mouseover
<static> | ColVis#dom.collection Collection list node
<static> | ColVis#dom.wrapper Wrapper for the button - given back to DataTables as the node to insert

Namespace Detail
ColVis#dom
Field Detail
<static> {Node} ColVis#dom.background
Background node used for shading the display and event capturing

Default Value:
  null

<static> {Node} ColVis#dom.button
Activation button

Default Value:
  null

<static> {Array} ColVis#dom.buttons
List of button elements

Default Value:
  []

<static> {Node} ColVis#dom.catcher
Element to position over the activation button to catch mouse events when using mouseover

Default Value:
  null

<static> {Node} ColVis#dom.collection
Collection list node

Default Value:
  null

<static> {Node} ColVis#dom.wrapper
Wrapper for the button - given back to DataTables as the node to insert

Default Value:
  null